@@ -54,7 +54,7 @@ def generate_alignment_bash(bash_file,ref,fq1,fq2,out_dir,gz = True):
             output.write(f'''
     bwa mem {ref} '<zcat {fq1}' '<zcat {fq2}' > {out_dir}/alignment.sam
     samtools view -bhS {out_dir}/alignment.sam > {out_dir}/alignment.bam
-    samtools sort -o {out_dir}/alignment.sort {out_dir}/alignment.bam
+    samtools sort {out_dir}/alignment.bam {out_dir}/alignment.sort 
     rm {out_dir}/alignment.sam
     echo \'alignment done\'
     ''')
@@ -62,7 +62,7 @@ def generate_alignment_bash(bash_file,ref,fq1,fq2,out_dir,gz = True):
             output.write(f'''
     bwa mem {ref} '<cat {fq1}' '<cat {fq2}' > {out_dir}/alignment.sam
     samtools view -bhS {out_dir}/alignment.sam > {out_dir}/alignment.bam
-    samtools sort -o {out_dir}/alignment.sort {out_dir}/alignment.bam
+    samtools sort {out_dir}/alignment.bam {out_dir}/alignment.sort 
     rm {out_dir}/alignment.sam
     echo \'alignment done\'
     ''')
@@ -95,7 +95,7 @@ RGPL=illumina \
 RGPU=NA \
 RGSM=sample \
 RGLB=sample
-samtools sort -o {out_dir}/alignment.RG.sort.bam {out_dir}/alignment.RG.bam
+samtools sort {out_dir}/alignment.RG.bam {out_dir}/alignment.RG.sort 
 samtools index {out_dir}/alignment.RG.sort.bam
 GenomeAnalysisTK \
 -T RealignerTargetCreator \
@@ -122,7 +122,7 @@ I={out_dir}/alignment.RG.indelre.sortbyQ.bam \
 O={out_dir}/alignment.RG.indelre.mkdup.bam \
 M={out_dir}/alignment.RG.indelre.mkdup.txt \
 TAGGING_POLICY=All ASSUME_SORT_ORDER=queryname
-samtools sort -o {out_dir}/alignment.RG.indelre.mkdup.sort.bam {out_dir}/alignment.RG.indelre.mkdup.bam
+samtools sort {out_dir}/alignment.RG.indelre.mkdup.bam {out_dir}/alignment.RG.indelre.mkdup.sort 
 samtools index {out_dir}/alignment.RG.indelre.mkdup.sort.bam
 echo \'indel alignment done\'''')
  
